import { inject, Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { BehaviorSubject, catchError, EMPTY, Observable, tap } from 'rxjs';
import { User } from '../model/User';

@Injectable({
  providedIn: 'root',
})
export class UserService {
  private http: HttpClient = inject(HttpClient);
  private currentUserSubject = new BehaviorSubject<User | null>(null);
  public currentUser$ = this.currentUserSubject.asObservable();

  constructor() {
    // Initialize with current user data
    this.getCurrentUser().subscribe();
  }

  public getUser(id: string): Observable<User | null> {
    return this.http.get<User | null>(`/backend/user/${id}`).pipe(
      catchError(() => EMPTY),
      tap((user) => this.currentUserSubject.next(user))
    );
  }

  public getCurrentUser(): Observable<User | null> {
    return this.http.get<User | null>('/backend/user').pipe(
      catchError(() => EMPTY),
      tap((user) => this.currentUserSubject.next(user))
    );
  }

  public refreshCurrentUser(): void {
    this.getCurrentUser().subscribe();
  }

  public createUser(id: string, username: string): Observable<User> {
    return this.http.post<User>('/backend/user', {
      authentikId: id,
      username: username,
    }).pipe(tap((user) => this.currentUserSubject.next(user)));
  }

  public getOrCreateUser(profile: any): Observable<User> {
    console.log('Full authentik profile:', profile);
    // Authentik format might differ from Keycloak
    // Check different possible locations for the ID and username
    const id = profile.info?.sub || profile['sub'];
    const username = profile.info?.preferred_username || profile['preferred_username'] || profile['email'] || profile['name'];

    if (!id || !username) {
      console.error('Could not extract user ID or username from profile', profile);
      throw new Error('Invalid user profile data');
    }

    console.log(`Creating user with id: ${id}, username: ${username}`);
    return this.createUser(id, username);
  }
}
